pub enum RefclockError {
NotSynchronized,
OffsetTooLarge,
Implausible,
Stale,
}Variants
NotSynchronized
The reference says it is not synchronized.
OffsetTooLarge
The offset is larger than any sane reference could imply.
Implausible
A timestamp was zero, negative or otherwise not a time.
Stale
This reading is not newer than the one before it.