pub fn select(sources: &[SourceEstimate]) -> SelectionExpand description
Find the largest clique of sources whose correctness intervals
[offset - root_distance, offset + root_distance] share a common point, then
combine the survivors.
pub fn select(sources: &[SourceEstimate]) -> SelectionFind the largest clique of sources whose correctness intervals
[offset - root_distance, offset + root_distance] share a common point, then
combine the survivors.